/**
 * Copyright (c) 2014 - 2019, Nordic Semiconductor ASA
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form, except as embedded into a Nordic
 *    Semiconductor ASA integrated circuit in a product or a software update for
 *    such product, must reproduce the above copyright notice, this list of
 *    conditions and the following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 3. Neither the name of Nordic Semiconductor ASA nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * 4. This software, with or without modification, must only be used with a
 *    Nordic Semiconductor ASA integrated circuit.
 *
 * 5. Any software provided in binary form under this license must not be reverse
 *    engineered, decompiled, modified and/or disassembled.
 *
 * THIS SOFTWARE IS PROVIDED BY NORDIC SEMICONDUCTOR ASA "AS IS" AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NORDIC SEMICONDUCTOR ASA OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

// Initialize the TWI communication.

#include "twi_driver.h"

i2c_sensors current_sensor = twi_BMI160;

// Indicates if operation on TWI has ended.
volatile bool twi_xfer_done = false;

// TWI instance.
static const nrf_drv_twi_t m_twi = NRF_DRV_TWI_INSTANCE(TWI_INSTANCE_ID);

// TWI initialization.
void init_twi(void) {
  ret_code_t err_code;

  const nrf_drv_twi_config_t twi_gi_pill_config = {
      .scl = ARDUINO_SCL_PIN,
      .sda = ARDUINO_SDA_PIN,
      .frequency = NRF_DRV_TWI_FREQ_100K,
      .interrupt_priority = APP_IRQ_PRIORITY_HIGH,
      .clear_bus_init = false};

  err_code = nrf_drv_twi_init(&m_twi, &twi_gi_pill_config, twi_handler, NULL);
  APP_ERROR_CHECK(err_code);

  nrf_drv_twi_enable(&m_twi);

  NRF_LOG_INFO("Initialization Complete: TWI Communication");
}

// TWI events handler. Called when I2C data is received.
//
// @details Dont put any long stuff in here. no print statements!!!
void twi_handler(nrf_drv_twi_evt_t const *p_event, void *p_context) {
  switch (p_event->type) {
  case NRF_DRV_TWI_EVT_DONE:
    if (p_event->xfer_desc.type == NRF_DRV_TWI_XFER_RX) {
      if (current_sensor == twi_BMI160) {              //{BMI160, LPS22HB, AD5241, MCP4017, MCP4725, LP55231};
        //data_handler_bmi160(gyroAccelData); //, GA_Done);
      } else if (current_sensor == twi_LPS22HB) {
        //data_handler_lps22hb(m_sample,pSample,tSample,lps_RX_Type,&checked,&ready);
        //LPSFLAG = 1;
        /*
          LPSFLAG=1;
          if(lps_RX_Type==TEMP){
            printTemp(((int16_t)((int16_t)tSample[1] << 8 | tSample[0])) / 100.f);
          }
          else if(lps_RX_Type == PRESSURE){
            printPressure(((int32_t)((int32_t)pSample[2] << 16 | (int32_t)pSample[1] << 8 | pSample[0])) / 4096.f);
          }
          else{}
        */

      } else if (current_sensor == twi_AD5241) {

      } else if (current_sensor == twi_MCP4017) {

      } else if (current_sensor == twi_MCP4725) {

      } else if (current_sensor == twi_LP55231) {

      } else {
        //yo you shouldnt be here...
      }
    }
    twi_xfer_done = true;
    break;
  default:
    break;
  }
}